Option Compare Text
''' -----------------------------------------------------------------------------
''' Project	 : Scandir
''' Class	 : ClsFifo
''' 
''' -----------------------------------------------------------------------------
''' <summary>
''' Classe de gestion d'une pile FIFO
''' </summary>
''' <remarks>
''' </remarks>
''' <history>
''' 	[nicolas]	22/10/2005	Created
''' </history>
''' -----------------------------------------------------------------------------
Public Class ClsFifo
    Protected mPile As Queue
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Constructeur de la classe, cr la pile
    ''' </summary>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Sub New()
        mPile = New Queue
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Ajoute un item dans la pile
    ''' </summary>
    ''' <param name="pObj">Objet  ajouter</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Sub PushData(ByRef pObj As Object)
        SyncLock mPile
            mPile.Enqueue(pObj)
        End SyncLock
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Cocatne la pile passe en paramtre avec celle de l'objet actuel
    ''' </summary>
    ''' <param name="pObjFifo">Pile  concatner</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Sub PushClsFifo(ByRef pObjFifo As ClsFifo)
        Do While pObjFifo.Count > 0
            PushData(pObjFifo.PopData)
        Loop
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Retire un lment de la pile
    ''' </summary>
    ''' <returns></returns>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Function PopData(Optional ByVal DelData As Boolean = True) As Object
        If IsNothing(mPile) Then Return Nothing
        SyncLock mPile
            If mPile.Count > 0 Then
                Dim mObj As Object
                If DelData Then
                    mObj = mPile.Dequeue
                Else
                    mObj = mPile.Peek
                End If
                Return mObj
            Else
                    Return Nothing
                End If
        End SyncLock
    End Function
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Retourne le nombre d'lment de la pile
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public ReadOnly Property Count() As Integer
        Get
            Return mPile.Count
        End Get
    End Property
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Vide la pile
    ''' </summary>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	24/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Sub Clear()
        SyncLock mPile
            mPile.Clear()
        End SyncLock
    End Sub
    Protected Overrides Sub Finalize()
        mPile = Nothing
        MyBase.Finalize()
    End Sub
End Class
''' -----------------------------------------------------------------------------
''' Project	 : Scandir
''' Class	 : ClsFifoStr
''' 
''' -----------------------------------------------------------------------------
''' <summary>
''' Parent : ClsFifo, spcialise la pile pour les string
''' </summary>
''' <remarks>
''' </remarks>
''' <history>
''' 	[nicolas]	22/10/2005	Created
''' </history>
''' -----------------------------------------------------------------------------
Public NotInheritable Class ClsFifoStr
    Inherits ClsFifo
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Constructeur de la classe, inutilis
    ''' </summary>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Sub New()
        MyBase.New()
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Cocatne la pile passe en paramtre avec celle de l'objet actuel
    ''' </summary>
    ''' <param name="pObjFifo">Pile  concatner</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Shadows Sub PushClsFifo(ByRef pObjFifo As ClsFifoStr)
        Do While pObjFifo.Count > 0
            PushData(pObjFifo.PopData)
        Loop
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Ajoute une chaine  la pile
    ''' </summary>
    ''' <param name="pStr">Chaine  ajouter</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Shadows Sub PushData(ByVal pStr As String)
        MyBase.PushData(CType(pStr, String))
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Ajoute les chaines contenues dans un tableau dans la pile
    ''' </summary>
    ''' <param name="pStr">!tableau de chaine</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	25/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Shadows Sub PushData(ByRef pStr As String())
        Dim i As Integer
        For i = 0 To pStr.GetUpperBound(0)
            PushData(pStr(i))
        Next
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Retire une chaine de la pile
    ''' </summary>
    ''' <returns></returns>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Shadows Function PopData(Optional ByVal DelData As Boolean = True) As String
        Dim mObj As Object = MyBase.PopData(DelData)
        If IsNothing(mObj) Then
            Return ""
        Else
            Return CType(mObj, String)
        End If
    End Function
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Trie la pile par ordre alphabtique
    ''' </summary>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Sub Sorted()
        SyncLock MyBase.mPile
            Dim ltData As New SortedList
            With MyBase.mPile
                If .Count() = 0 Then Exit Sub
                Dim Tmp As String
                Do While .Count() > 0
                    Tmp = CType(.Dequeue, String)
                    ltData.Add(Tmp, Tmp)
                Loop
                .Clear()
                Do While ltData.Count > 0
                    .Enqueue(ltData.GetByIndex(0))
                    ltData.RemoveAt(0)
                Loop
            End With
        End SyncLock
    End Sub
    Protected Overrides Sub Finalize()
        MyBase.Finalize()
    End Sub
End Class
''' -----------------------------------------------------------------------------
''' Project	 : Scandir
''' Class	 : ClsFifoFile
''' 
''' -----------------------------------------------------------------------------
''' <summary>
''' Parent : ClsFifo, spcialise la pile pour les TFile
''' </summary>
''' <remarks>
''' </remarks>
''' <history>
''' 	[nicolas]	22/10/2005	Created
''' </history>
''' -----------------------------------------------------------------------------
Public NotInheritable Class ClsFifoFile
    Inherits ClsFifo
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Constructeur de la classe, inutilis
    ''' </summary>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Sub New()
        MyBase.New()
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Cocatne la pile passe en paramtre avec celle de l'objet actuel
    ''' </summary>
    ''' <param name="pObjFifo">Pile  concatner</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Shadows Sub PushClsFifo(ByRef pObjFifo As ClsFifoFile)
        Do While pObjFifo.Count > 0
            PushData(pObjFifo.PopData)
        Loop
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Ajoute une chaine  la pile
    ''' </summary>
    ''' <param name="pStr">TFile  ajouter</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Shadows Sub PushData(ByVal pStr As TFile)
        MyBase.PushData(CType(pStr, TFile))
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Ajoute un FileInfo  la pile
    ''' </summary>
    ''' <param name="pStr">Objet FileInfo</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	25/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Shadows Sub PushData(ByRef pStr As System.IO.FileInfo)
        PushData(New TFile(pStr.FullName))
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Ajoute un tableau de TFile  la pile
    ''' </summary>
    ''' <param name="pStr">Tableau de TFile</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	25/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Shadows Sub PushData(ByRef pStr As TFile())
        Dim i As Integer
        For i = 0 To pStr.GetUpperBound(0)
            PushData(pStr(i))
        Next
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Ajoute un tableau de fileinfo  la pile
    ''' </summary>
    ''' <param name="pStr">Tableau de FileInfo</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	25/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Shadows Sub PushData(ByRef pStr As System.IO.FileInfo())
        Dim i As Integer
        For i = 0 To pStr.GetUpperBound(0)
            PushData(pStr(i))
        Next
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Retire une TFile de la pile
    ''' </summary>
    ''' <returns></returns>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Shadows Function PopData(Optional ByVal DelData As Boolean = True) As TFile
        Dim mObj As Object = MyBase.PopData(DelData)
        If IsNothing(mObj) Then
            Return New TFile("")
        Else
            Return CType(mObj, TFile)
        End If
    End Function
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Trie la pile par ordre alphabtique
    ''' </summary>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Sub Sorted()
        SyncLock MyBase.mPile
            If MyBase.mPile.Count() = 0 Then Exit Sub

            Dim ltData As New SortedList
            Dim lFile As TFile
            Do While MyBase.mPile.Count > 0
                lFile = CType(MyBase.mPile.Dequeue(), TFile)
                If ltData.Item(lFile.FileTitle.ToLower) Is Nothing Then
                    ltData.Add(lFile.FileTitle.ToLower, lFile)
                End If
            Loop
            Do While ltData.Count > 0
                MyBase.mPile.Enqueue(ltData.GetByIndex(0))
                ltData.RemoveAt(0)
            Loop
        End SyncLock
    End Sub
    Protected Overrides Sub Finalize()
        MyBase.Finalize()
    End Sub
End Class
''' -----------------------------------------------------------------------------
''' Project	 : Scandir
''' Class	 : ClsFifoPath
''' 
''' -----------------------------------------------------------------------------
''' <summary>
''' Parent : ClsFifo, spcialise la pile pour les string
''' </summary>
''' <remarks>
''' </remarks>
''' <history>
''' 	[nicolas]	22/10/2005	Created
''' </history>
''' -----------------------------------------------------------------------------
Public NotInheritable Class ClsFifoPath
    Inherits ClsFifo
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Constructeur de la classe, inutilis
    ''' </summary>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Sub New()
        MyBase.New()
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Cocatne la pile passe en paramtre avec celle de l'objet actuel
    ''' </summary>
    ''' <param name="pObjFifo">Pile  concatner</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Shadows Sub PushClsFifo(ByRef pObjFifo As ClsFifoPath)
        Do While pObjFifo.Count > 0
            PushData(pObjFifo.PopData)
        Loop
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Ajoute une TPath  la pile
    ''' </summary>
    ''' <param name="pStr">Chaine  ajouter</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Shadows Sub PushData(ByVal pStr As TPath)
        MyBase.PushData(CType(pStr, TPath))
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Ajoute un DirectoryInfo  la pile
    ''' </summary>
    ''' <param name="pStr">Objet DirectoryInfo</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	25/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Shadows Sub PushData(ByRef pStr As System.IO.DirectoryInfo)
        PushData(New TPath(pStr.FullName))
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Ajoute un tableau de TPath  la pile
    ''' </summary>
    ''' <param name="pStr">Tableau de TPath</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	25/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Shadows Sub PushData(ByRef pStr As TPath())
        Dim i As Integer
        For i = 0 To pStr.GetUpperBound(0)
            PushData(pStr(i))
        Next
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Ajoute un Tableau de DirectoryInfo  la pile
    ''' </summary>
    ''' <param name="pStr">Tableau de DirectoryInfo</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	25/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Shadows Sub PushData(ByRef pStr As System.IO.DirectoryInfo())
        Dim i As Integer
        For i = 0 To pStr.GetUpperBound(0)
            PushData(pStr(i))
        Next
    End Sub
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Retire une TPath de la pile
    ''' </summary>
    ''' <returns></returns>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Shadows Function PopData(Optional ByVal DelData As Boolean = True) As TPath
        Dim mObj As Object = MyBase.PopData(DelData)
        If IsNothing(mObj) Then
            Return New TPath("")
        Else
            Return CType(mObj, TPath)
        End If
    End Function
    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Trie la pile par ordre alphabtique
    ''' </summary>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[nicolas]	22/10/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Sub Sorted()
        SyncLock MyBase.mPile
            With MyBase.mPile
                If .Count() = 0 Then Exit Sub
                Dim ltData As New SortedList
                Dim lPath As TPath
                Dim Tmp As String
                Do While .Count > 0
                    lPath = CType(.Dequeue, TPath)
                    ltData.Add(lPath.Path.ToLower, lPath)
                Loop
                Do While ltData.Count > 0
                    .Enqueue(ltData.GetByIndex(0))
                    ltData.RemoveAt(0)
                Loop
            End With
        End SyncLock
    End Sub
    Protected Overrides Sub Finalize()
        MyBase.Finalize()
    End Sub
End Class
